Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Accumulator ¶
Accumulator is an object that can accumulate statistics based on individual objects within a context.
func Pipeline ¶
func Pipeline( ctx context.Context, in chan interface{}, newAccumulator func() Accumulator, ) Accumulator
Pipeline runs a concurrent processing pipeline that executes a given function for every value read off of an input channel. The KeyValue object provided to the processor function is only accessable to one of the go routines within the pipeline.
type Float64 ¶
func NewFloat64 ¶
func NewFloat64() Float64
Click to show internal directories.
Click to hide internal directories.